==> cloud-5.1.1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/views/field/OpenStackRemoveRouterInterface.php <==
<?php

namespace Drupal\openstack\Plugin\views\field;

use Drupal\Core\Access\AccessManagerInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A handler to provide a field that is completely custom by the administrator.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("openstack_remove_router_interface")
 */
class OpenStackRemoveRouterInterface extends FieldPluginBase {

  /**
   * Constructs a LinkBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Access\AccessManagerInterface $access_manager
   *   The access manager.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    AccessManagerInterface $access_manager,
    RouteMatchInterface $route_match) {

    parent::__construct($configuration, $plugin_id, $plugin_definition, $access_manager);

    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('access_manager'),
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function usesGroupBy() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $build = [
      '#type' => 'operations',
      '#links' => [
        [
          'title' => $this->t('Remove interface'),
          'url' => Url::fromRoute(
            'entity.openstack_router.remove_interface_form',
            [
              'cloud_context' => $values->_entity->getCloudContext(),
              'openstack_router' => $this->routeMatch->getParameter('openstack_router'),
              'openstack_port' => $values->_entity->id(),
            ]
          ),
        ],
      ],
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
  }

}

==> cloud-6.0.0-rc4.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/views/field/OpenStackRemoveRouterInterface.php <==
<?php

namespace Drupal\openstack\Plugin\views\field;

use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A handler to provide a field that is completely custom by the administrator.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("openstack_remove_router_interface")
 */
class OpenStackRemoveRouterInterface extends FieldPluginBase {

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Constructs a LinkBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    RouteMatchInterface $route_match) {

    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function usesGroupBy() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $build = [
      '#type' => 'operations',
      '#links' => [
        [
          'title' => $this->t('Remove interface'),
          'url' => Url::fromRoute(
            'entity.openstack_router.remove_interface_form',
            [
              'cloud_context' => $values->_entity->getCloudContext(),
              'openstack_router' => $this->routeMatch->getParameter('openstack_router'),
              'openstack_port' => $values->_entity->id(),
            ]
          ),
        ],
      ],
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
  }

}
